[GitHub] [mynewt-nimble] KKopyscinski opened a new pull request #937: mesh: add relay config restrictions

2021-03-16 Thread GitBox


KKopyscinski opened a new pull request #937:
URL: https://github.com/apache/mynewt-nimble/pull/937


   BLE_MESH_RELAY_ENABLED, BLE_MESH_RELAY_RETRANSMIT_COUNT and
   BLE_MESH_RELAY_RETRANSMIT_INTERVAL should be configured only if
   BT_MESH_RELAY is on



This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
us...@infra.apache.org




[GitHub] [mynewt-nimble] KKopyscinski opened a new pull request #938: host: fail pairing in SC only when peripheral doesn't support SC

2021-03-16 Thread GitBox


KKopyscinski opened a new pull request #938:
URL: https://github.com/apache/mynewt-nimble/pull/938


   If we, as central, send pairing request  in SC only mode we can
   receive pairing response with with SC pairing not supported flag
   in AuthReq. In this case we should fail pairing with BLE_SM_ERR_AUTHREQ
   error.
   
   This is required to pass GAP/SEC/SEM/BV-28-C



This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
us...@infra.apache.org




[GitHub] [mynewt-core] apache-mynewt-bot commented on pull request #2530: mcu/fe310: Fix hal timer

2021-03-16 Thread GitBox


apache-mynewt-bot commented on pull request #2530:
URL: https://github.com/apache/mynewt-core/pull/2530#issuecomment-800114912


   
   
   
   ## Style check summary
   
    No suggestions at this time!
   



This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
us...@infra.apache.org




[GitHub] [mynewt-core] apache-mynewt-bot removed a comment on pull request #2530: mcu/fe310: Fix hal timer

2021-03-16 Thread GitBox


apache-mynewt-bot removed a comment on pull request #2530:
URL: https://github.com/apache/mynewt-core/pull/2530#issuecomment-799684868


   
   
   
   ## Style check summary
   
    No suggestions at this time!
   



This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
us...@infra.apache.org




[GitHub] [mynewt-nimble] KKopyscinski commented on pull request #937: mesh: add relay config restrictions

2021-03-16 Thread GitBox


KKopyscinski commented on pull request #937:
URL: https://github.com/apache/mynewt-nimble/pull/937#issuecomment-800116727


   1/4   MESHMESH/NODE/RLY/BV-01-C   PASS62.644 
 
   2/4   MESHMESH/NODE/RLY/BV-02-C   PASS107.084
  
   3/4   MESHMESH/NODE/RLY/BI-01-C   PASS34.706 
 
   4/4   MESHMESH/NODE/RLY/BI-02-C   PASS40.362  



This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
us...@infra.apache.org




[GitHub] [mynewt-nimble] apache-mynewt-bot commented on pull request #938: host: fail pairing in SC only when peripheral doesn't support SC

2021-03-16 Thread GitBox


apache-mynewt-bot commented on pull request #938:
URL: https://github.com/apache/mynewt-nimble/pull/938#issuecomment-800127333


   
   
   
   ## Style check summary
   
    No suggestions at this time!
   



This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
us...@infra.apache.org




[GitHub] [mynewt-nimble] apache-mynewt-bot commented on pull request #937: mesh: add relay config restrictions

2021-03-16 Thread GitBox


apache-mynewt-bot commented on pull request #937:
URL: https://github.com/apache/mynewt-nimble/pull/937#issuecomment-800130850


   
   
   
   ## Style check summary
   
    No suggestions at this time!
   



This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
us...@infra.apache.org




[mynewt-core] branch master updated: mcu/fe310: Fix hal timer

2021-03-16 Thread jerzy
This is an automated email from the ASF dual-hosted git repository.

jerzy pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/mynewt-core.git


The following commit(s) were added to refs/heads/master by this push:
 new 4b650d3  mcu/fe310: Fix hal timer
4b650d3 is described below

commit 4b650d3fdcddd930a71507fdee1cf7398583be40
Author: Jerzy Kasenberg 
AuthorDate: Mon Mar 15 17:37:45 2021 +0100

mcu/fe310: Fix hal timer

Hal timer was not correctly setting up compare timer resulting
in interrupts firing at wrong time.
Problem was hidden if hal timer operated at high frequencies.
For low hal_timer frequencies variable ticks is often low
and it this low value was put in CMP1 comparator while
counter was already past this value resulting in immediate
trigger of interrupt.
In CMP1 interrupt pattern was repeated.
Now CMP1 is set to value that is greater then PWMS, if it would
be grater then CMP0 (which is maximum value of counter) it is not
set at the moment of check, it will be set in CMP0 interrupt.
---
 hw/mcu/sifive/fe310/src/hal_timer.c | 41 -
 1 file changed, 27 insertions(+), 14 deletions(-)

diff --git a/hw/bus/src/bus.c b/hw/bus/src/bus.c
index 265cf02..ce5188a 100644
--- a/hw/bus/src/bus.c
+++ b/hw/bus/src/bus.c
@@ -238,6 +238,10 @@ bus_dev_init_func(struct os_dev *odev, void *arg)
 /* XXX allow custom eventq */
 os_callout_init(&bdev->inactivity_tmo, os_eventq_dflt_get(),
 bus_dev_inactivity_tmo_func, odev);
+bdev->pm_mode = MYNEWT_VAL_CHOICE(BUS_PM_MODE, AUTO) ? BUS_PM_MODE_AUTO : 
BUS_PM_MODE_MANUAL;
+if (MYNEWT_VAL_CHOICE(BUS_PM_MODE, AUTO)) {
+bdev->pm_opts.pm_mode_auto.disable_tmo = 
MYNEWT_VAL(BUS_PM_INACTIVITY_TMO);
+}
 #endif
 
 #if MYNEWT_VAL(BUS_STATS)
diff --git a/hw/bus/syscfg.yml b/hw/bus/syscfg.yml
index 0303470..f9ac0e6 100644
--- a/hw/bus/syscfg.yml
+++ b/hw/bus/syscfg.yml
@@ -37,6 +37,22 @@ syscfg.defs:
 allows for some automatic management of bus device state instead of
 implementing this manually.
 value: 0
+BUS_PM_MODE:
+description: >
+Default power management mode for bus drivers.  When set to AUTO
+bus drivers will take care of turning off controllers when they
+are not needed for some time.
+When set to MANUAL bus driver will not enable/disable controllers
+leaving it to the application code.
+This setting is only valid when BUS_PM == 1.
+choices:
+- AUTO
+- MANUAL
+value: AUTO
+BUS_PM_INACTIVITY_TMO:
+description: >
+Default inactivity time after which bus controller will be 
disabled (in ticks).
+value: 1
 
 BUS_STATS:
 description: >



[mynewt-core] 02/02: hw/bus: Enable bus device in non automatic mode

2021-03-16 Thread jerzy
This is an automated email from the ASF dual-hosted git repository.

jerzy pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/mynewt-core.git

commit 6c41549ac45b37f2c3b4f435216a6a9f480a5ab3
Author: Jerzy Kasenberg 
AuthorDate: Fri Feb 26 14:47:28 2021 +0100

hw/bus: Enable bus device in non automatic mode

Function bus_dev_enable was called during bus controller initialization.
When automatic mode with timeout was enabled but there was no activity
on the bus, controller stayed enabled till it was used first time
which activated timeout that would disable bus.

Now when automatic mode is enabled BUS_PM = 1 and BUS_PM_MODE = AUTO
bus is not enabled before first use to conserve power.
---
 hw/bus/src/bus.c | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

diff --git a/hw/bus/src/bus.c b/hw/bus/src/bus.c
index ce5188a..58712df 100644
--- a/hw/bus/src/bus.c
+++ b/hw/bus/src/bus.c
@@ -256,7 +256,9 @@ bus_dev_init_func(struct os_dev *odev, void *arg)
 odev->od_handlers.od_suspend = bus_dev_suspend_func;
 odev->od_handlers.od_resume = bus_dev_resume_func;
 
-bus_dev_enable(bdev);
+if (!MYNEWT_VAL(BUS_PM) || MYNEWT_VAL_CHOICE(BUS_PM_MODE, MANUAL)) {
+bus_dev_enable(bdev);
+}
 
 return 0;
 }



[GitHub] [mynewt-artifact] agross-korg merged pull request #31: Fix encrypted image support

2021-03-16 Thread GitBox


agross-korg merged pull request #31:
URL: https://github.com/apache/mynewt-artifact/pull/31


   



This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
us...@infra.apache.org




[mynewt-artifact] branch master updated: Fix encrypted image support

2021-03-16 Thread agross
This is an automated email from the ASF dual-hosted git repository.

agross pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/mynewt-artifact.git


The following commit(s) were added to refs/heads/master by this push:
 new 64169ed  Fix encrypted image support
 new 21a0320  Merge pull request #31 from utzig/fix-encrypted-images
64169ed is described below

commit 64169ed99ee78ce7b12445fd389907199470d808
Author: Fabio Utzig 
AuthorDate: Mon Mar 15 20:13:49 2021 -0300

Fix encrypted image support

When encrypting images, the hash was being calculated using the
encrypted image body. This is invalid for MCUboot, the hash must be
calculated first from the plain body and afterwards this body must be
encrypted. This commit fixes the behavior.

Signed-off-by: Fabio Utzig 
---
 image/create.go | 19 ++-
 1 file changed, 14 insertions(+), 5 deletions(-)

diff --git a/image/create.go b/image/create.go
index 129baaa..0217f2c 100644
--- a/image/create.go
+++ b/image/create.go
@@ -553,19 +553,28 @@ func (ic *ImageCreator) Create() (Image, error) {
img.Header.ProtSz = calcProtSize(img.ProtTlvs)
 
// Followed by data.
+   var hashBytes []byte
+   var err error
if ic.PlainSecret != nil {
+   // For encrypted images, must calculate the hash with the plain
+   // body and encrypt the payload afterwards
+   img.Body = append(img.Body, ic.Body...)
+   hashBytes, err = img.CalcHash(ic.InitialHash)
+   if err != nil {
+   return img, err
+   }
encBody, err := sec.EncryptAES(ic.Body, ic.PlainSecret, 
ic.Nonce)
if err != nil {
return img, err
}
+   img.Body = nil
img.Body = append(img.Body, encBody...)
} else {
img.Body = append(img.Body, ic.Body...)
-   }
-
-   hashBytes, err := img.CalcHash(ic.InitialHash)
-   if err != nil {
-   return img, err
+   hashBytes, err = img.CalcHash(ic.InitialHash)
+   if err != nil {
+   return img, err
+   }
}
 
// Hash TLV.



[mynewt-artifact] tag v0.0.22 created (now 21a0320)

2021-03-16 Thread utzig
This is an automated email from the ASF dual-hosted git repository.

utzig pushed a change to tag v0.0.22
in repository https://gitbox.apache.org/repos/asf/mynewt-artifact.git.


  at 21a0320  (commit)
No new revisions were added by this update.



[GitHub] [mynewt-newt] utzig opened a new pull request #432: Update to mynewt-artifact v0.0.22

2021-03-16 Thread GitBox


utzig opened a new pull request #432:
URL: https://github.com/apache/mynewt-newt/pull/432


   Also run `go mod tidy` to clean up dependencies.



This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
us...@infra.apache.org




[GitHub] [mynewt-core] apache-mynewt-bot removed a comment on pull request #2534: doc: Fix post_link_cmds newt extcmd documentation

2021-03-16 Thread GitBox


apache-mynewt-bot removed a comment on pull request #2534:
URL: https://github.com/apache/mynewt-core/pull/2534#issuecomment-800405702


   
   
   
   ## Style check summary
   
    No suggestions at this time!
   



This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
us...@infra.apache.org




[GitHub] [mynewt-core] apache-mynewt-bot commented on pull request #2534: doc: Fix post_link_cmds newt extcmd documentation

2021-03-16 Thread GitBox


apache-mynewt-bot commented on pull request #2534:
URL: https://github.com/apache/mynewt-core/pull/2534#issuecomment-800654079


   
   
   
   ## Style check summary
   
    No suggestions at this time!
   



This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
us...@infra.apache.org




[GitHub] [mynewt-core] simonratner opened a new issue #2535: Compiler packages for appcore and netcore of nRF5340

2021-03-16 Thread GitBox


simonratner opened a new issue #2535:
URL: https://github.com/apache/mynewt-core/issues/2535


   Commit disabling DSP instructions for M-33 suggests creating a custom 
compiler package for BSPs that need it: 
https://github.com/apache/mynewt-core/commit/bafc7e0e08057502d26fd7b84c89ac341c80e970.
   
   Given that nRF5340 appcore and netcore BSPs are in-tree, and appcore 
supports DSP instruction set while the netcore does not, I think the two 
compiler packages themselves should be in the tree: `arm-none-eabi-m33` and 
`arm-none-eabi-m33-nodsp`, so that the corresponding Nordic BSPs can be used 
directly from the repo.



This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
us...@infra.apache.org




[GitHub] [mynewt-nimble] KKopyscinski merged pull request #938: host: fail pairing in SC only when peripheral doesn't support SC

2021-03-16 Thread GitBox


KKopyscinski merged pull request #938:
URL: https://github.com/apache/mynewt-nimble/pull/938


   



This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
us...@infra.apache.org




[mynewt-nimble] branch master updated: host: fail pairing in SC only when peripheral doesn't support SC

2021-03-16 Thread kopyscinski
This is an automated email from the ASF dual-hosted git repository.

kopyscinski pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/mynewt-nimble.git


The following commit(s) were added to refs/heads/master by this push:
 new 32621d0  host: fail pairing in SC only when peripheral doesn't support 
SC
32621d0 is described below

commit 32621d01b444d99dedba8fe85c44a2bb1b2460c4
Author: Krzysztof Kopyściński 
AuthorDate: Tue Mar 16 09:42:33 2021 +0100

host: fail pairing in SC only when peripheral doesn't support SC

If we, as central, send pairing request  in SC only mode we can
receive pairing response with with SC pairing not supported flag
in AuthReq. In this case we should fail pairing with BLE_SM_ERR_AUTHREQ
error.

This is required to pass GAP/SEC/SEM/BV-28-C
---
 nimble/host/src/ble_sm.c | 3 +++
 1 file changed, 3 insertions(+)

diff --git a/nimble/host/src/ble_sm.c b/nimble/host/src/ble_sm.c
index d405589..b4e8096 100644
--- a/nimble/host/src/ble_sm.c
+++ b/nimble/host/src/ble_sm.c
@@ -1886,6 +1886,9 @@ ble_sm_pair_rsp_rx(uint16_t conn_handle, struct os_mbuf 
**om,
 } else if (rsp->max_enc_key_size > BLE_SM_PAIR_KEY_SZ_MAX) {
 res->sm_err = BLE_SM_ERR_INVAL;
 res->app_status = BLE_HS_SM_US_ERR(BLE_SM_ERR_INVAL);
+} else if (!ble_sm_verify_auth_requirements(rsp->authreq)) {
+res->sm_err = BLE_SM_ERR_AUTHREQ;
+res->app_status = BLE_HS_SM_US_ERR(BLE_SM_ERR_AUTHREQ);
 } else {
 ble_sm_pair_cfg(proc);
diff --git a/hw/mcu/sifive/fe310/src/hal_timer.c 
b/hw/mcu/sifive/fe310/src/hal_timer.c
index 3b59f20..23e2ae1 100644
--- a/hw/mcu/sifive/fe310/src/hal_timer.c
+++ b/hw/mcu/sifive/fe310/src/hal_timer.c
@@ -30,7 +30,8 @@
 
 struct fe310_hal_tmr {
 void *pwm_regs; /* Pointer to timer registers */
-uint32_t value; /* Acumulated timer value, incremented on CMP0 */
+uint32_t value; /* Accumulated timer value, incremented on CMP0 */
+uint16_t pwms;  /* Value of register pwms taken when value was set 
*/
 uint8_t max_scale;  /* Max value for pwmcfg.pwmscale 7 (for PMW0) or 
15 (for PWM1/2) */
 uint8_t pwmxcmp0_int;   /* PWMxCMP0 interrupt number */
 TAILQ_HEAD(hal_timer_qhead, hal_timer) sht_timers;
@@ -38,17 +39,23 @@ struct fe310_hal_tmr {
 
 #if MYNEWT_VAL(TIMER_0)
 struct fe310_hal_tmr fe310_pwm2 = {
-(uint32_t *) PWM2_CTRL_ADDR, 0, 15, INT_PWM2_BASE
+.pwm_regs = (uint32_t *)PWM2_CTRL_ADDR,
+.max_scale = 15,
+.pwmxcmp0_int = INT_PWM2_BASE,
 };
 #endif
 #if MYNEWT_VAL(TIMER_1)
 struct fe310_hal_tmr fe310_pwm1 = {
-(uint32_t *) PWM1_CTRL_ADDR, 0, 15, INT_PWM1_BASE
+.pwm_regs = (uint32_t *)PWM1_CTRL_ADDR,
+.max_scale = 15,
+.pwmxcmp0_int = INT_PWM1_BASE,
 };
 #endif
 #if MYNEWT_VAL(TIMER_2)
 struct fe310_hal_tmr fe310_pwm0 = {
-(uint32_t *) PWM0_CTRL_ADDR, 0, 7, INT_PWM0_BASE
+.pwm_regs = (uint32_t *)PWM0_CTRL_ADDR,
+.max_scale = 7,
+.pwmxcmp0_int = INT_PWM0_BASE,
 };
 #endif
 
@@ -80,7 +87,8 @@ hal_timer_cnt(struct fe310_hal_tmr *tmr)
 uint32_t regs = (uint32_t) tmr->pwm_regs;
 
 __HAL_DISABLE_INTERRUPTS(sr);
-cnt = _REG32(regs, PWM_S) + tmr->value;
+tmr->pwms = _REG32(regs, PWM_S);
+cnt = tmr->pwms + tmr->value;
 /* Check if just overflowed */
 if (_REG32(regs, PWM_CFG) & PWM_CMP0) {
 cnt += _REG32(regs, PWM_CMP0) + 1;
@@ -94,13 +102,18 @@ static void
 fe310_tmr_check_first(struct fe310_hal_tmr *tmr)
 {
 struct hal_timer *ht;
+uint32_t cnt;
+int32_t ticks;
 
 ht = TAILQ_FIRST(&tmr->sht_timers);
 if (ht) {
-uint32_t cnt = hal_timer_cnt(tmr);
-int32_t ticks = (int32_t)(ht->expiry - cnt);
-if (ticks < _REG32(tmr->pwm_regs, PWM_CMP0)) {
-_REG32(tmr->pwm_regs, PWM_CMP1) = ticks;
+cnt = hal_timer_cnt(tmr);
+ticks = (int32_t)(ht->expiry - cnt);
+/*
+ * Setup CMP1 only when it would need to fire before CMP0.
+ */
+if (tmr->pwms + ticks < _REG32(tmr->pwm_regs, PWM_CMP0)) {
+_REG32(tmr->pwm_regs, PWM_CMP1) = tmr->pwms + ticks;
 plic_enable_interrupt(tmr->pwmxcmp0_int + 1);
 return;
 }
@@ -138,7 +151,7 @@ fe310_pwm_cmp0_handler(int num)
 int pwm_num = (num - INT_PWM0_BASE) >> 2;
 int timer_num = pwm_to_timer[pwm_num];
 struct fe310_hal_tmr *tmr = fe310_tmr_devs[timer_num];
-/* Turn of CMPxIP */
+/* Clear interrupt flag CMP0IP */
 _REG32(tmr->pwm_regs, PWM_CFG) &= ~PWM_CFG_CMP0IP;
 tmr->value += _REG32(tmr->pwm_regs, PWM_CMP0) + 1;
 fe310_tmr_cbs(tmr);
@@ -150,7 +163,8 @@ fe310_pwm_cmp1_handler(int num)
 int pwm_num = (num - INT_PWM0_BASE) >> 2;
 int timer_num = pwm_to_timer[pwm_num];
 struct fe310_hal_tmr *tmr = fe310_tmr_devs[timer_num];
-/* Turn of CMPxIP */
+/* Clear interrupt flag CMP1IP */
+_REG32(tmr->pwm_regs, PWM_CMP1) = _REG32(tmr->pwm_regs, PWM_CMP0);
 _REG32(tmr->pwm_regs, PWM_CFG) &= ~PWM_CFG_CMP1IP;
 fe310_tmr_cbs(tmr);
 }
@@ -168,10 +182,9 @@ fe310_pwm_cmp1_handler(int num)
 int
 hal_timer_init(int timer_num, void *cfg)
 {
-struct fe310_hal_tmr *tmr;
+(void)cfg;
 
-if (timer_num >= FE310_HAL_TIMER_MAX || !(tmr = fe310_tmr_devs[time

[GitHub] [mynewt-core] kasjer merged pull request #2530: mcu/fe310: Fix hal timer

2021-03-16 Thread GitBox


kasjer merged pull request #2530:
URL: https://github.com/apache/mynewt-core/pull/2530


   



This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
us...@infra.apache.org




[GitHub] [mynewt-nimble] KKopyscinski commented on pull request #937: mesh: add relay config restrictions

2021-03-16 Thread GitBox


KKopyscinski commented on pull request #937:
URL: https://github.com/apache/mynewt-nimble/pull/937#issuecomment-800209953


   corrected restrictions; tests are still passing



This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
us...@infra.apache.org




[GitHub] [mynewt-nimble] apache-mynewt-bot commented on pull request #937: mesh: add relay config restrictions

2021-03-16 Thread GitBox


apache-mynewt-bot commented on pull request #937:
URL: https://github.com/apache/mynewt-nimble/pull/937#issuecomment-800215519


   
   
   
   ## Style check summary
   
    No suggestions at this time!
   



This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
us...@infra.apache.org




[GitHub] [mynewt-nimble] apache-mynewt-bot removed a comment on pull request #937: mesh: add relay config restrictions

2021-03-16 Thread GitBox


apache-mynewt-bot removed a comment on pull request #937:
URL: https://github.com/apache/mynewt-nimble/pull/937#issuecomment-800130850


   
   
   
   ## Style check summary
   
    No suggestions at this time!
   



This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
us...@infra.apache.org




[GitHub] [mynewt-nimble] apache-mynewt-bot commented on pull request #937: mesh: BLE_MESH_RELAY_ENABLED should have BLE_MESH_RELAY as default value

2021-03-16 Thread GitBox


apache-mynewt-bot commented on pull request #937:
URL: https://github.com/apache/mynewt-nimble/pull/937#issuecomment-800228761


   
   
   
   ## Style check summary
   
    No suggestions at this time!
   



This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
us...@infra.apache.org




[GitHub] [mynewt-nimble] apache-mynewt-bot removed a comment on pull request #937: mesh: BLE_MESH_RELAY_ENABLED should have BLE_MESH_RELAY as default value

2021-03-16 Thread GitBox


apache-mynewt-bot removed a comment on pull request #937:
URL: https://github.com/apache/mynewt-nimble/pull/937#issuecomment-800215519


   
   
   
   ## Style check summary
   
    No suggestions at this time!
   



This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
us...@infra.apache.org




[GitHub] [mynewt-core] utzig opened a new pull request #2534: doc: Fix post_link_cmds newt extcmd documentation

2021-03-16 Thread GitBox


utzig opened a new pull request #2534:
URL: https://github.com/apache/mynewt-core/pull/2534


   The `post_build_cmds` step was renamed to `post_link_cmds` with 
https://github.com/apache/mynewt-newt/commit/39005b80a6a034244061898c1b610dd7e4e34a36
   
   Fix extcmd documentation appropriately.



This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
us...@infra.apache.org




[GitHub] [mynewt-core] apache-mynewt-bot commented on pull request #2534: doc: Fix post_link_cmds newt extcmd documentation

2021-03-16 Thread GitBox


apache-mynewt-bot commented on pull request #2534:
URL: https://github.com/apache/mynewt-core/pull/2534#issuecomment-800405702


   
   
   
   ## Style check summary
   
    No suggestions at this time!
   



This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
us...@infra.apache.org




[GitHub] [mynewt-newtmgr] dnsglk commented on issue #178: Failed to upload image over BLE using zephyr

2021-03-16 Thread GitBox


dnsglk commented on issue #178:
URL: https://github.com/apache/mynewt-newtmgr/issues/178#issuecomment-800483001


   @AnanthJaisankar Hi, could you tell please what was the cause for this issue 
? 



This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
us...@infra.apache.org




[mynewt-core] branch master updated (4b650d3 -> 6c41549)

2021-03-16 Thread jerzy
This is an automated email from the ASF dual-hosted git repository.

jerzy pushed a change to branch master
in repository https://gitbox.apache.org/repos/asf/mynewt-core.git.


from 4b650d3  mcu/fe310: Fix hal timer
 new 54f08ca  hw/bus: Allow automatic power mode from syscfg
 new 6c41549  hw/bus: Enable bus device in non automatic mode

The 2 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "add" were already present in the repository and have only
been added to this reference.


Summary of changes:
 hw/bus/src/bus.c  |  8 +++-
 hw/bus/syscfg.yml | 16 
 2 files changed, 23 insertions(+), 1 deletion(-)



[GitHub] [mynewt-core] kasjer merged pull request #2506: Bus driver power management improvments

2021-03-16 Thread GitBox


kasjer merged pull request #2506:
URL: https://github.com/apache/mynewt-core/pull/2506


   



This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

For queries about this service, please contact Infrastructure at:
us...@infra.apache.org




[mynewt-core] 01/02: hw/bus: Allow automatic power mode from syscfg

2021-03-16 Thread jerzy
This is an automated email from the ASF dual-hosted git repository.

jerzy pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/mynewt-core.git

commit 54f08cafd0e6ae475c6535371db830d7e13c6405
Author: Jerzy Kasenberg 
AuthorDate: Fri Feb 26 14:16:24 2021 +0100

hw/bus: Allow automatic power mode from syscfg

Bus driver with BUS_PM enabled was defaulting to manual
mode. User code still was required to call bus_dev_set_pm
function to switch to automatic mode.
Now BUS_PM_MODE configuration value is provided that allows
starting in automatic mode from the beginning.

Automatic mode is also chosen as default mode when BUS_PM is enabled.

Inactivity timeout (time after which bus goes to power save mode)
now can be specified in syscfg with BUS_PM_INACTIVITY_TMO value.
---
 hw/bus/src/bus.c  |  4 
 hw/bus/syscfg.yml | 16 
 2 files changed, 20 insertions(+)
